==> question2answer-1.3-language-ru.zip: ru/qa-lang-emails.php <==
﻿<?php
	
/*
	Question2Answer 1.3 (c) 2010, Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-lang-emails.php
	Version: 1.3
	Date: 2010-11-27 12:12:11 GMT
	Description: Language phrases for email notifications


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'a_commented_body' => "На Ваш ответ, на сайте ^site_title, добавлен новый комментарий от ^c_handle:\n\n^open^c_content^close\n\nВаш ответ был:\n\n^open^c_context^close\n\nВы можете ответить добавив свой комментарий:\n\n^url\n\nСпасибо,\n\n^site_title",
		'a_commented_subject' => 'На Ваш ответ, на сайте ^site_title, добавлен новый комментарий',
		'a_followed_body' => "На Ваш ответ, на сайте ^site_title, был задан связанный вопрос от ^q_handle:\n\n^open^q_title^close\n\nВаш ответ был:\n\n^open^a_content^close\n\nНажмите на ссылку ниже, чтобы ответить на новый вопрос:\n\n^url\n\nСпасибо,\n\n^site_title",
		'a_followed_subject' => 'На Ваш ответ, на сайте ^site_title, задан связанный вопрос',
		'a_selected_body' => "Поздравляем! Ваш ответ, на сайте ^site_title, ^s_handle выбрал(а) лучшим:\n\n^open^a_content^close\n\nВопрос был:\n\n^open^q_title^close\n\nНажмите ниже, чтобы увидеть Ваш ответ на сайте:\n\n^url\n\nСпасибо,\n\n^site_title",
		'a_selected_subject' => 'Ваш ответ на сайте, ^site_title, признан лучшим!',
		'c_commented_body' => "Новый комментарий от ^c_handle был добавлен после Вашего комментария на сайте ^site_title:\n\n^open^c_content^close\n\nНовый комментарий:\n\n^open^c_context^close\n\nВы можете ответить добавив другой комментарий:\n\n^url\n\nСпасибо,\n\n^site_title",
		'c_commented_subject' => 'После Вашего комментария, на сайте ^site_title, был добавлен новый',
		'confirm_body' => "Пожалуйста, нажмите на ссылку ниже, чтобы подтвердить Ваш адрес электронной почты для сайта ^site_title.\n\n^url\n\nСпасибо,\n^site_title",
		'confirm_subject' => '^site_title - Подтверждение адреса эл. почты.',
		'feedback_body' => "Комментарии:\n^message\n\nИмя:\n^name\n\nE-mail:\n^email\n\nСо страницы:\n^previous\n\nПользователь:\n^url\n\nIP-адрес:\n^ip\n\nБраузер:\n^browser",
		'feedback_subject' => '^ отзыв',
		'new_password_body' => "^Ваш новый пароль для сайта ^site_title.\n\nПароль: ^password\n\nРекомендуется изменить его сразу после входа на сайт\n\nСпасибо,\n^site_title\n^url",
		'new_password_subject' => '^site_title - Новый пароль',
		'q_answered_body' => "На Ваш вопрос, на сайте ^site_title, добавлен ответ от ^a_handle:\n\n^open^a_content^close\n\nВаш вопрос был:\n\n^open^q_title^close\n\nЕсли Вам понравился этот ответ, то Вы можете выбрать его лучшим :\n\n^url\n\nСпасибо,\n\n^site_title",
		'q_answered_subject' => 'На Ваш вопрос, на сайте ^site_title, есть ответ',
		'q_commented_body' => "На Ваш вопрос, на сайте ^site_title, добавлен новый комментарий от ^c_handle:\n\n^open^c_content^close\n\nВаш вопрос был:\n\n^open^c_context^close\n\nYВы можете ответить добавив свой комментарий:\n\n^url\n\nСпасибо,\n\n^site_title",
		'q_commented_subject' => 'На Ваш вопрос, на сайте ^site_title, добавлен комментарий',
		'q_posted_body' => "Новый вопрос от ^q_handle:\n\n^open^q_title\n\n^q_content^close\n\nНажмите ниже, чтобы ответить:\n\n^url\n\nСпасибо,\n\n^site_title",
		'q_posted_subject' => 'Добавлен новый вопрос на сайте ^site_title',
		'reset_body' => "Нажмите ниже, чтобы сменить пароль для сайта^site_title.\n\n^url\n\nВведите код, написанный ниже, на сайте.\n\nCode: ^code\n\nЕсли Вы не просили сменить пароль, тогда проигнорируйте это письмо. Не отвечайте на него.\n\nСпасибо,\n^site_title",
		'reset_subject' => '^site_title - Смена пароля',
		'welcome_body' => "Спасибо за регистрацию на сайте ^site_title.\n\n^custom^confirmВаши данные:\n\nE-mail: ^email\nПароль: ^password\n\nДержите Ваш пароль в секрете\n\nСпасибо,\n\n^site_title\n^url",
		'welcome_confirm' => "Пожалуйста, нажмите на ссылку ниже, чтобы подтвердить Ваш адрес электронной почты.\n\n^url\n\n",
		'welcome_subject' => 'Добро пожаловать на сайт ^site_title!',
		);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.4-language-ru.zip: ru/qa-lang-emails.php <==
<?php
	
/*
	Question2Answer 1.4.1 (c) 2011, Gideon Greenspan

	http://www.question2answer.org/

    File: qa-lang/ru/qa-lang-emails.php
	Version: 1.4.1
	Date: 2011-08-20
	Description: Русификация Question2Answer 1.4
	Translation: Starozhuk Anatoliy / http://facknet.ru/ 

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'a_commented_body' => "На Ваш ответ, на сайте ^site_title, добавлен новый комментарий от ^c_handle:\n\n^open^c_content^close\n\nВаш ответ был:\n\n^open^c_context^close\n\nВы можете ответить добавив свой комментарий:\n\n^url\n\nСпасибо,\n\n^site_title",
		'a_commented_subject' => 'На Ваш ответ, на сайте ^site_title, добавлен новый комментарий',
		'a_followed_body' => "На Ваш ответ, на сайте ^site_title, был задан связанный вопрос от ^q_handle:\n\n^open^q_title^close\n\nВаш ответ был:\n\n^open^a_content^close\n\nНажмите на ссылку ниже, чтобы ответить на новый вопрос:\n\n^url\n\nСпасибо,\n\n^site_title",
		'a_followed_subject' => 'На Ваш ответ, на сайте ^site_title, задан связанный вопрос',
		'a_selected_body' => "Поздравляем! Ваш ответ, на сайте ^site_title, ^s_handle выбрал(а) лучшим:\n\n^open^a_content^close\n\nВопрос был:\n\n^open^q_title^close\n\nНажмите ниже, чтобы увидеть Ваш ответ на сайте:\n\n^url\n\nСпасибо,\n\n^site_title",
		'a_selected_subject' => 'Ваш ответ на сайте, ^site_title, признан лучшим!',
		'c_commented_body' => "Новый комментарий от ^c_handle был добавлен после Вашего комментария на сайте ^site_title:\n\n^open^c_content^close\n\nНовый комментарий:\n\n^open^c_context^close\n\nВы можете ответить добавив другой комментарий:\n\n^url\n\nСпасибо,\n\n^site_title",
		'c_commented_subject' => 'После Вашего комментария, на сайте ^site_title, был добавлен новый',
		'confirm_body' => "Пожалуйста, нажмите на ссылку ниже, чтобы подтвердить Ваш адрес электронной почты для сайта ^site_title.\n\n^url\n\nСпасибо,\n^site_title",
		'confirm_subject' => '^site_title - Подтверждение адреса эл. почты.',
		'feedback_body' => "Комментарии:\n^message\n\nИмя:\n^name\n\nE-mail:\n^email\n\nСо страницы:\n^previous\n\nПользователь:\n^url\n\nIP-адрес:\n^ip\n\nБраузер:\n^browser",
		'feedback_subject' => '^ отзыв',
		'new_password_body' => "^Ваш новый пароль для сайта ^site_title.\n\nПароль: ^password\n\nРекомендуется изменить его сразу после входа на сайт\n\nСпасибо,\n^site_title\n^url",
		'new_password_subject' => '^site_title - Новый пароль',
		'q_answered_body' => "На Ваш вопрос, на сайте ^site_title, добавлен ответ от ^a_handle:\n\n^open^a_content^close\n\nВаш вопрос был:\n\n^open^q_title^close\n\nЕсли Вам понравился этот ответ, то Вы можете выбрать его лучшим :\n\n^url\n\nСпасибо,\n\n^site_title",
		'q_answered_subject' => 'На Ваш вопрос, на сайте ^site_title, есть ответ',
		'q_commented_body' => "На Ваш вопрос, на сайте ^site_title, добавлен новый комментарий от ^c_handle:\n\n^open^c_content^close\n\nВаш вопрос был:\n\n^open^c_context^close\n\nYВы можете ответить добавив свой комментарий:\n\n^url\n\nСпасибо,\n\n^site_title",
		'q_commented_subject' => 'На Ваш вопрос, на сайте ^site_title, добавлен комментарий',
		'q_posted_body' => "Новый вопрос от ^q_handle:\n\n^open^q_title\n\n^q_content^close\n\nНажмите ниже, чтобы ответить:\n\n^url\n\nСпасибо,\n\n^site_title",
		'q_posted_subject' => 'Добавлен новый вопрос на сайте ^site_title',
		'reset_body' => "Нажмите ниже, чтобы сменить пароль для сайта^site_title.\n\n^url\n\nВведите код, написанный ниже, на сайте.\n\nCode: ^code\n\nЕсли Вы не просили сменить пароль, тогда проигнорируйте это письмо. Не отвечайте на него.\n\nСпасибо,\n^site_title",
		'reset_subject' => '^site_title - Смена пароля',
		'welcome_body' => "Спасибо за регистрацию на сайте ^site_title.\n\n^custom^confirmВаши данные:\n\nE-mail: ^email\nПароль: ^password\n\nДержите Ваш пароль в секрете\n\nСпасибо,\n\n^site_title\n^url",
		'flagged_subject' => '^site_title отмечены сообщения',
		'welcome_subject' => 'Добро пожаловать на сайт ^site_title!',
		'flagged_body' => 'Пост ^p_handle имеет ^flags:\n\n^open^p_context^close , что бы получить\n\nНажмите на ссылку ниже, что бы посмотреть сообщение:\n^url,\n\n^site_title',
		'private_message_subject' => 'Сообщение от ^f_handle на сайте ^site_title',
		'private_message_body' => 'У вас есть личное сообщение с ^f_handle auf ^site_title:\n\n^open^message^close получить.\n\n^more,\n\n^site_title\n\n\nUm что бы отключить личные сообщения пожалуйста войдите в свой аккаунт на сайте:\n^a_url',
		'welcome_confirm' => "Пожалуйста, нажмите на эту ссылку, чтобы подтвердить свой адрес электронной почты:\n^url\n\n",
		'private_message_info' => "Более подробную информацию о ^f_handle:\n^url\n\n",
		'private_message_reply' => "Нажмите на ссылку, чтобы ^f_handle ответить на личное сообщение:\n^url\n\n",
		);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
